<?php
namespace Pinpoint\PaymentIcons\ViewModel;

class GetOptions implements \Magento\Framework\View\Element\Block\ArgumentInterface
{
    public function __construct(
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        $this->scopeConfig = $scopeConfig;
        $this->storeManager = $storeManager;
    }
       
    public function isEnabled():bool {
        return $this->scopeConfig->isSetFlag("paymenticons/general/enabled",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());
    }

    public function showLabel():bool {
        return $this->scopeConfig->isSetFlag("paymenticons/general/show_label",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());
    }

    public function getLabelText():string {
        return $this->scopeConfig->getValue("paymenticons/general/label_text",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "Payment Methods";
    }

    public function getPaymentIcons():array {
        $PaymentIcons = $this->scopeConfig->getValue("paymenticons/general/payment_icons",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId());

        // If the payment icons are not set, return an empty array
        if (!$PaymentIcons) {
            return [];
        }

        // Explode the comma-separated list of payment icons into an array and return
        return explode(",", $PaymentIcons);
    }

    public function getIconStyle():string {
        return $this->scopeConfig->getValue("paymenticons/display/icon_style",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? "color-dark";
    }

    public function getIconSize():int {
        return $this->scopeConfig->getValue("paymenticons/display/icon_size",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 32;
    }

    public function getIconSpacing():int {
        return $this->scopeConfig->getValue("paymenticons/display/icon_spacing",
        \Magento\Store\Model\ScopeInterface::SCOPE_STORE,$this->storeManager->getStore()->getStoreId()) ?? 6;
    }
}
